﻿
using System;
using System.Windows;
using System.Windows.Media;


namespace CustomMonthCalendar
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();

			calendar.MonthSettings.HeaderStyles = MindFusion.Scheduling.Wpf.MonthHeaderStyles.None;
			calendar.MonthSettings.WeekHeaderStyle = MindFusion.Scheduling.Wpf.MonthWeekHeaderStyle.Left;

			var headerBrush = new LinearGradientBrush(
				new GradientStopCollection(
					new GradientStop[]
					{
						new GradientStop(Color.FromArgb(255, 228, 236, 246), 0),
						new GradientStop(Color.FromArgb(255, 214, 226, 241), 0.45),
						new GradientStop(Color.FromArgb(255, 194, 212, 235), 0.55),
						new GradientStop(Color.FromArgb(255, 208, 222, 239), 1),
					}), 90);

			calendar.MonthSettings.DaySettings.CalendarStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 74, 126, 187));
			calendar.MonthSettings.DaySettings.CalendarStyle.BorderThickness = new Thickness(1);
			calendar.MonthSettings.DaySettings.HeaderStyle.Background = headerBrush;
			calendar.MonthSettings.DaySettings.HeaderStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 141, 174, 217));
			calendar.MonthSettings.DaySettings.HeaderStyle.BorderThickness = new Thickness(0, 0, 0, 1);
			calendar.MonthSettings.DaySettings.HeaderStyle.FontWeight = FontWeights.Bold;
			calendar.MonthSettings.DaySettings.HeaderStyle.ContentMargin = new Thickness(2);
			calendar.MonthSettings.DaySettings.HeaderStyle.HorizontalAlignment = System.Windows.HorizontalAlignment.Stretch;
			calendar.MonthSettings.DaySettings.HeaderStyle.TextAlignment = TextAlignment.Left;
			calendar.MonthSettings.DaySettings.FirstDayOfMonthFormat = "MMM d";

			calendar.MonthSettings.PaddingDaysStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 74, 126, 187));
			calendar.MonthSettings.PaddingDaysStyle.BorderThickness = new Thickness(1);
			calendar.MonthSettings.PaddingDaysStyle.Background = new SolidColorBrush(Color.FromArgb(255, 165, 191, 225));
			calendar.MonthSettings.PaddingDaysHeaderStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 141, 174, 217));
			calendar.MonthSettings.PaddingDaysHeaderStyle.BorderThickness = new Thickness(0, 0, 0, 1);
			calendar.MonthSettings.PaddingDaysHeaderStyle.Background = headerBrush;
			calendar.MonthSettings.PaddingDaysHeaderStyle.FontWeight = FontWeights.Bold;
			calendar.MonthSettings.PaddingDaysHeaderStyle.ContentMargin = new Thickness(2);
			calendar.MonthSettings.PaddingDaysHeaderStyle.HorizontalAlignment = System.Windows.HorizontalAlignment.Stretch;
			calendar.MonthSettings.PaddingDaysHeaderStyle.TextAlignment = TextAlignment.Left;
			calendar.MonthSettings.PaddingDaysHeaderStyle.Foreground = Brushes.Black;

			calendar.MonthSettings.SubHeaderStyle.Background = new SolidColorBrush(Color.FromArgb(255, 227, 239, 255));

			calendar.CellPresenterCreating += calendar_CellPresenterCreating;

			r = new Random(DateTime.Now.Millisecond);
		}

		Random r;

		void calendar_CellPresenterCreating(object sender, MindFusion.Scheduling.CellPresenterCreatingEventArgs e)
		{
			var presenter = new CustomCellPresenter(calendar);
			var info = new CellInfo()
			{
				New = r.Next(128),
				Refill = r.Next(255),
				Change = r.Next(64),
				Extend = r.Next(16),
			};
			info.Total = info.New + info.Refill + info.Change + info.Extend;
			presenter.CellInfo = info;
			e.CellPresenter = presenter;
		}
	}
}
